@@ -35,6 +35,7 @@ class RNVideoPlayer: RCTView {
   var _moviePathSource: NSString = ""
   var _playerStartTime: CGFloat = 0
   var _playerEndTime: CGFloat = 0
+  var _replay: Bool = false
 
   let LOG_KEY: String = "VIDEO_PROCESSING"
 
@@ -94,7 +95,7 @@ class RNVideoPlayer: RCTView {
           if val != nil && player != nil {
             let floatVal = val as! CGFloat
             if floatVal <= self._playerEndTime && floatVal >= self._playerStartTime {
-              player.seek(to: CMTimeMakeWithSeconds(Float64(val!), Int32(NSEC_PER_SEC)))
+              self.player.seek(to: convertToCMTime(val: floatVal))
             }
           }
         }
@@ -178,6 +179,17 @@ class RNVideoPlayer: RCTView {
     }
   }
 
+  var replay: NSNumber? {
+    set(val) {
+      if val != nil  {
+        self._replay = RCTConvert.bool(val!)
+      }
+    }
+    get {
+      return nil
+    }
+  }
+
   var volume: NSNumber? {
     set(val) {
       let minValue: NSNumber = 0
@@ -230,13 +242,30 @@ class RNVideoPlayer: RCTView {
       queue: nil,
       using: {(_ time: CMTime) -> Void in
         let currentTime = CGFloat(CMTimeGetSeconds(time))
+        self.onVideoCurrentTimeChange(currentTime: currentTime)
         if currentTime >= self._playerEndTime {
+          if self._replay {
+            return self.replayMovie()
+          }
           self.play = 0
         }
       }
     )
   }
 
+  func replayMovie() {
+    if player != nil {
+      self.player.seek(to: convertToCMTime(val: self._playerStartTime))
+      self.player.play()
+    }
+  }
+
+  func onVideoCurrentTimeChange(currentTime: CGFloat) {
+    if (self.bridge != nil && self.bridge.eventDispatcher() != nil) {
+      let event = ["currentTime": currentTime]
+      self.bridge.eventDispatcher().sendAppEvent(withName: "VIDEO_PROCESSING_EVENT_CURRENT_TIME", body: event)
+    }
+  }
 
   // start player
   func startPlayer() {
